% MATLAB GMM REGRESSIONS FOR ECOM PROJECT
% 128 MB REGRESSIONS

% August 20, 2008

% LOG
clear all

diary('gmm128g.dia')

% SELECT GMM options  : see documentation for more details
% THESE OPTIONS ARE USED IN ALL THE REGRESSIONS, UNINSTRUMENTED
% OR NOT BELOW

% --- Set GMM options ----------------------------------------------------
disp('---------------------------------------------------------------------')
%   gmmopt  structure of gmm options                            [default]
%   gmmopt.infoz   Nested structure of infoz needed in MINZ
%   gmmopt.infoz.momt  Filename of moment conditions            REQUIRED
%   gmmopt.infoz.jake  Filename of Jacobian of moment cond      ['numz']
%   gmmopt.infoz.hess  Hessian updating (see gmmS function)     ['gn']
%
%   gmmopt.gmmit  Number of GMM iterations (NaN is iterated)	[2]
%   gmmopt.maxit  Cap on number of GMM iterations		[25]
%   gmmopt.tol    Convergence criteria for iter. GMM		[1e-7]
%   gmmopt.W0     Initial GMM weighting matrix			['Z']
%	'I' = Identity, 'Z' = Instruments (Z'Z), 'C' = Calculate from b, 
%       'Win' = Fixed passed as Win, myfile = user's own m-file
%   gmmopt.W      Subsequent GMM Weighting Matrix               ['S']
%       'S' = inverse Spectral Density from gmmS
%       myfile = user's m-file name
%   gmmopt.S      Type of Spectral Density matrix		['NW']
%	'W'=White, 'NW'=Newey-West (Bartlett), 'G'=Gallant (Parzen)
%	'H'=Hansen (Truncated), 'AM'=Andrews-Monahan
%   gmmopt.aminfo structure if gmmopt.S='AM'.   See ANDMON.M
%   gmmopt.lags   Lags used in truncated kernel for S	        [nobs^(1/3)]
%   gmmopt.wtvec  User-provided vector of wts for truncated kernel
%   gmmopt.Strim  Contols demeaning of moments in calc of S	[1]
%	0 = none, 1 = detrend e, 2 = detrend Z'e
%   gmmopt.Slast  1 to recalc S at final param est. 2 updates W	[1]
%   gmmopt.null   Vector of null hypotheses for t-stats		[0]
%   gmmopt.prt    Fid for printing (0=none,1=screen,else file)	[1]

%   gmmopt.plot   1 does some plots, else suppress		[1]
%   gmmopt.vname  Optional k-vector of parameter names
%
% Y  "Dependent" variables
% X  "Independent" variables
% Z  Instruments (can be same as X)
% Win User-defined Initial weighting matrix                     OPTIONAL
%    To use a function to calculate W0, don't use Win, but set
%    gmmopt.W0 to 'U' and give the m-file name in gmmopt.W
%

infoz.momt='gmmnb';			% moment conditions
infoz.jake='gmmnbj';			% Analytical Deriv of moment cond.

infoz.step='step2';			% Step length algorithm
infoz.hess='bfgs';			%b Hessian (search direction)
infoz.maxit = 200;                  % Number of interations per GMM iteration
gmmopt.infoz = infoz;
gmmopt.gmmit = 10;			% Number of GMM iterations
gmmopt.W0 = 'Z';			% Initial weighting matrix
gmmopt.W='S';				% Subsequent wtg matrix optimal
gmmopt.S='NW';				% Select subsequent wtg matrix
gmmopt.lags=5;				% Lags in weighting matrix
gmmopt.prt=1;				% Control printing
gmmopt.plot=0;				% change to 1 if you want various plots of the moment conditions


%-----------------------------------------------------------------------------
% REGRESSIONS WITHOUT INSTRUMENTS

disp('=====================================')
disp('---REGRESSIONS WITHOUT INSTRUMENTS---')
disp('=====================================')

% LOAD DATA
data=csvread('ml128.csv');

% order of variables is : 
% 1. numdate, 2. s, 3. cnum, 4. q1, 5. q2, 6. q3, 7. border, 8. weekend, 9.
% boost, 10. lnp1, 11. lnp2, 12. lnp3, 13. lnminp, 14. t1, 15. t2, 16. t3, 
% 17. t4, 18. t5, 19. t6, 20. t7, 21. t8, 22. t9, 23. t10, 24. t11, 25. t12, 
% 26. rankc, 27. ip1cnew, 28. ip2c, 29. ip3c, 30. irankos, 31. ip1os, 
% 32. ip2os, 33. ip3os, 34. r1, 35. r2, 36. r3, 37. r4, 38. r5, 39. r6, 
% 40. r7, 41. r8, 42. r9, 43. r10, 44. r11, 45. r12

%rows with last observation :
%s=0, cnum=1:   343
%s=0, cnum=2:   683
%s=3, cnum=1:   989
%s=3, cnum=2:  1291

numdate=data(:,1);
s=data(:,2);
cnum=data(:,3);
q1=data(:,4);
q2=data(:,5);
q3=data(:,6);
border=data(:,7);
weekend=data(:,8);
boost=data(:,9);
lnp1=data(:,10);
lnp2=data(:,11);
lnp3=data(:,12);
lnminp=data(:,13);
t1=data(:,14);
t2=data(:,15);
t3=data(:,16);
t4=data(:,17);
t5=data(:,18);
t6=data(:,19);


t7=data(:,20);
t8=data(:,21);
t9=data(:,22);
t10=data(:,23);
t11=data(:,24);
t12=data(:,25);
irankc=data(:,26);
ip1cnew=data(:,27);
ip2c=data(:,28);
ip3c=data(:,29);
irankos=data(:,30);
ip1os=data(:,31);
ip2os=data(:,32);
ip3os=data(:,33);
r1=data(:,34);
r2=data(:,35);
r3=data(:,36);
r4=data(:,37);
r5=data(:,38);
r6=data(:,39);
r7=data(:,40);
r8=data(:,41);
r9=data(:,42);
r10=data(:,43);
r11=data(:,44);
r12=data(:,45);

cons=ones(1291,1);

%------------------------------------------------------------------------------
% PC 100

% For Table 2 of the main text, Elasticities.xls, and Graphs.xls 
% nbreg q1 border lnp1 lnp2 lnp3 lnminp weekend boost t1-t12 if s==0
disp('=====================================')
disp('---REGRESSIONS WITHOUT INSTRUMENTS---')
disp('--------------128 MB PC100-----------')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(1:683,:);
X =[cons(1:683,:) lnp1(1:683,:) lnp2(1:683,:) lnp3(1:683,:) lnminp(1:683,:) border(1:683,:) weekend(1:683,:) boost(1:683,:) t1(1:683,:) t2(1:683,:) t3(1:683,:) t4(1:683,:) t5(1:683,:) t6(1:683,:) t7(1:683,:) t8(1:683,:) t9(1:683,:) t10(1:683,:) t11(1:683,:) t12(1:683,:)];
Z=X;
T1=343;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','border','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;-1;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
gmmopt.null = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('----------------  NO INSTRUMENTS ----------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('----------------  NO INSTRUMENTS ----------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors

%---------------------------------------------------------------------
%  For Graphs.xls
% nbreg q1 lnp1 lnp2 lnp3 lnminp weekend boost rank1-rank12 t1-t12 if s==0
disp('=====================================')
disp('---REGRESSIONS WITHOUT INSTRUMENTS---')
disp('-----------MODEL WITH RANK DUMMIES---')
disp('--------------128 MB PC100-----------')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(1:683,:);
X =[cons(1:683,:) lnp1(1:683,:) lnp2(1:683,:) lnp3(1:683,:) lnminp(1:683,:) weekend(1:683,:) boost(1:683,:) r1(1:683,:) r2(1:683,:) r3(1:683,:) r4(1:683,:) r5(1:683,:) r6(1:683,:) r7(1:683,:) r8(1:683,:) r9(1:683,:) r10(1:683,:) r11(1:683,:) r12(1:683,:) t1(1:683,:) t2(1:683,:) t3(1:683,:) t4(1:683,:) t5(1:683,:) t6(1:683,:) t7(1:683,:) t8(1:683,:) t9(1:683,:) t10(1:683,:) t11(1:683,:) t12(1:683,:)];
Z=X;
T1=343;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','weekend', 'boost', 'r1','r2','r3','r4','r5','r6','r7','r8','r9','r10','r11','r12','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;0;0;0;-.1;-.2;-.3;-.4;-.5;-.6;-.7;-.8;-.9;-1;-1.1;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
% Starting values
gmmopt.null = zeros(31,1);	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('----------------  NO INSTRUMENTS ----------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('----------------  NO INSTRUMENTS ----------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors

%------------------------------------------------------------------------------
% PC 100

% For Table 3 of the supplementary material and Graphs.xls
% nbreg q1 lnp1 lnp2 lnp3 lnminp weekend boost rank2m rank4m rank6m rank12m r12mdum t1-t12 if s==0

rank=exp(border(1:683,:))-ones(683,1);
rank2m=max([2*ones(1,683)-rank'; zeros(1,683)])';
rank4m=max([4*ones(1,683)-rank'; zeros(1,683)]);
rank4m=min([rank4m;2*ones(1,683)])';
rank6m=max([6*ones(1,683)-rank'; zeros(1,683)]);
rank6m=min([rank6m;2*ones(1,683)])';
rank12m=max([12*ones(1,683)-rank'; zeros(1,683)]);
rank12m=min([rank12m;6*ones(1,683)])';
rank12mdum=(rank'<=12*ones(1,683))';

disp('=====================================')
disp('---REGRESSIONS WITHOUT INSTRUMENTS---')
disp('------PIECEWISE LINEAR IN RANKS -----')
disp('--------------128 MB PC100-----------')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(1:683,:);
X =[cons(1:683,:) lnp1(1:683,:) lnp2(1:683,:) lnp3(1:683,:) lnminp(1:683,:) rank2m rank4m rank6m rank12m rank12mdum weekend(1:683,:) boost(1:683,:) t1(1:683,:) t2(1:683,:) t3(1:683,:) t4(1:683,:) t5(1:683,:) t6(1:683,:) t7(1:683,:) t8(1:683,:) t9(1:683,:) t10(1:683,:) t11(1:683,:) t12(1:683,:)];
Z=X;
T1=343;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','rank2m', 'rank4m','rank6m','rank12m','rank12mdum','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
gmmopt.null = zeros(24,1);	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('----------------  NO INSTRUMENTS ----------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('----------------  NO INSTRUMENTS ----------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


%------------------------------------------------------------------------------
% PC 133

% For Elasticities.xls
% nbreg q1 border lnp1 lnp2 lnp3 lnminp weekend boost t1-t12 if s==3
disp('=====================================')
disp('---REGRESSIONS WITHOUT INSTRUMENTS---')
disp('--------------128 MB PC133-----------')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(684:1291,:);
X =[cons(684:1291,:) lnp1(684:1291,:) lnp2(684:1291,:) lnp3(684:1291,:) lnminp(684:1291,:) border(684:1291,:) weekend(684:1291,:) boost(684:1291,:) t1(684:1291,:) t2(684:1291,:) t3(684:1291,:) t4(684:1291,:) t5(684:1291,:) t6(684:1291,:) t7(684:1291,:) t8(684:1291,:) t9(684:1291,:) t10(684:1291,:) t11(684:1291,:) t12(684:1291,:)];
Z=X;
T1=306;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','border','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;-1;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
gmmopt.null = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('----------------  NO INSTRUMENTS ----------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(684:1291,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('----------------  NO INSTRUMENTS ----------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(684:1291,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


%------------------------------------------------------------------------------
% PC 100

% For Table 5 of the main text
disp('=====================================')
disp('----- COST BASED INSTRUMENTS---------')
disp('--------------128 MB PC100-----------')
disp('----- ---IP1CNEW, IP2C, IP3C---------')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(1:683,:);
X =[cons(1:683,:) lnp1(1:683,:) lnp2(1:683,:) lnp3(1:683,:) lnminp(1:683,:) border(1:683,:) weekend(1:683,:) boost(1:683,:) t1(1:683,:) t2(1:683,:) t3(1:683,:) t4(1:683,:) t5(1:683,:) t6(1:683,:) t7(1:683,:) t8(1:683,:) t9(1:683,:) t10(1:683,:) t11(1:683,:) t12(1:683,:)];
Z =[cons(1:683,:) ip1cnew(1:683,:) ip2c(1:683,:) ip3c(1:683,:) lnminp(1:683,:) border(1:683,:) weekend(1:683,:) boost(1:683,:) t1(1:683,:) t2(1:683,:) t3(1:683,:) t4(1:683,:) t5(1:683,:) t6(1:683,:) t7(1:683,:) t8(1:683,:) t9(1:683,:) t10(1:683,:) t11(1:683,:) t12(1:683,:)];
T1=343;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','border','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;-1;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
gmmopt.null = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('-------------------------------------------------')
disp('-- COST-BASED INSTRUMENTS: IP1CNEW, IP2C, IP3C---')
disp('-------------------------------------------------')
disp('-------------128MB PC100 MEMORY------------------')
disp('-------------------------------------------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('-------------------------------------------------')
disp('-- COST-BASED INSTRUMENTS: IP1CNEW, IP2C, IP3C---')
disp('-------------------------------------------------')
disp('-------------128MB PC100 MEMORY------------------')
disp('-------------------------------------------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(1:683,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


%------------------------------------------------------------------------------
% PC 100

data=csvread('ml128s.csv');

% order of variables is : 
% 1. numdate, 2. s, 3. cnum, 4. q1, 5. q2, 6. q3, 7. border, 8. weekend, 9.
% boost, 10. lnp1, 11. lnp2, 12. lnp3, 13. lnminp, 14. t1, 15. t2, 16. t3, 
% 17. t4, 18. t5, 19. t6, 20. t7, 21. t8, 22. t9, 23. t10, 24. t11, 25. t12, 
% 26. irankc, 27. ip1cnew, 28. ip2c, 29. ip3c, 30. irankos, 31. ip1os, 
% 32. ip2os, 33. ip3os, 34. r1, 35. r2, 36. r3, 37. r4, 38. r5, 39. r6, 
% 40. r7, 41. r8, 42. r9, 43. r10, 44. r11, 45. r12

%rows with last observation :
%s=0, cnum=1: 306
%s=0, cnum=2: 608
%s=3, cnum=1: 914
%s=3, cnum=2: 1216

numdate=data(:,1);
s=data(:,2);
cnum=data(:,3);
q1=data(:,4);
q2=data(:,5);
q3=data(:,6);
border=data(:,7);
weekend=data(:,8);
boost=data(:,9);
lnp1=data(:,10);
lnp2=data(:,11);
lnp3=data(:,12);
lnminp=data(:,13);
t1=data(:,14);
t2=data(:,15);
t3=data(:,16);
t4=data(:,17);
t5=data(:,18);
t6=data(:,19);


t7=data(:,20);
t8=data(:,21);
t9=data(:,22);
t10=data(:,23);
t11=data(:,24);
t12=data(:,25);
irankc=data(:,26);
ip1cnew=data(:,27);
ip2c=data(:,28);
ip3c=data(:,29);
irankos=data(:,30);
ip1os=data(:,31);
ip2os=data(:,32);
ip3os=data(:,33);
r1=data(:,34);
r2=data(:,35);
r3=data(:,36);
r4=data(:,37);
r5=data(:,38);
r6=data(:,39);
r7=data(:,40);
r8=data(:,41);
r9=data(:,42);
r10=data(:,43);
r11=data(:,44);
r12=data(:,45);


%----------------------------------------------------------------

% For Table 5 of the main text
disp('=====================================')
disp('------- OTHER-SPEED INSTRUMENTS -----')
disp('--------------128 MB PC100-----------')
disp('----IRANKOS, IP1OS, IP2OS, IP3OS-----')
disp('-------------------------------------------------')
disp('-------------------LOW QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q1(1:608,:);
X =[cons(1:608,:) lnp1(1:608,:) lnp2(1:608,:) lnp3(1:608,:) lnminp(1:608,:) border(1:608,:) weekend(1:608,:) boost(1:608,:) t1(1:608,:) t2(1:608,:) t3(1:608,:) t4(1:608,:) t5(1:608,:) t6(1:608,:) t7(1:608,:) t8(1:608,:) t9(1:608,:) t10(1:608,:) t11(1:608,:) t12(1:608,:)];
Z =[cons(1:608,:) ip1os(1:608,:) ip2os(1:608,:) ip3os(1:608,:) lnminp(1:608,:) irankos(1:608,:) weekend(1:608,:) boost(1:608,:) t1(1:608,:) t2(1:608,:) t3(1:608,:) t4(1:608,:) t5(1:608,:) t6(1:608,:) t7(1:608,:) t8(1:608,:) t9(1:608,:) t10(1:608,:) t11(1:608,:) t12(1:608,:)];
T1=343;  % number of observations for the first firm
gmmopt.vname = strvcat('cons','lnp1','lnp2','lnp3','lnminp','border','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11','t12');	% variable names
b=[5;0;0;0;0;-1;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	      % Starting values
gmmopt.null = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];	% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors


disp('-------------------------------------------------')
disp('-OTHER-SPEED INSTRUMENTS: IP1OS, IP2OS, IP3OS, IRANKOS--')
disp('-------------------------------------------------')
disp('-------------128MB PC100 MEMORY------------------')
disp('-------------------------------------------------')
disp('-------------------MED QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q2(1:608,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors
%------------------------------------------------------------------------------
% HIGH QUALITY
disp('-------------------------------------------------')
disp('---OTHER-SPEED INSTRUMENTS: IP1OS, IP2OS, IP3OS, IRANKOS--')
disp('-------------------------------------------------')
disp('-------------128MB PC100 MEMORY------------------')
disp('-------------------------------------------------')
disp('------------------HIGH QUALITY-------------------')
disp(' N-W SEs for each station, indep across stations ')
disp('-------------------------------------------------')
Y = q3(1:608,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);  % call the gmm procedure which will call for the newey-west within firm standard errors




diary off;
