% MATLAB GMM REGRESSIONS FOR ECOM PROJECT
% 256 MB  AND ATHLON CPU REGRESSIONS

% October 31, 2002

% Modified June 12, 2003 to run from Nathan's folder, using the same X
% matrix as in gmm128.m

% LOG
clear all

diary('gmm256g.dia')

% SELECT GMM options  : see documentation for more details
% THESE OPTIONS ARE USED IN ALL THE REGRESSIONS, UNINSTRUMENTED
% OR NOT BELOW

% --- Set GMM options ----------------------------------------------------
disp('---------------------------------------------------------------------')
%   gmmopt  structure of gmm options                            [default]
%   gmmopt.infoz   Nested structure of infoz needed in MINZ
%   gmmopt.infoz.momt  Filename of moment conditions            REQUIRED
%   gmmopt.infoz.jake  Filename of Jacobian of moment cond      ['numz']
%   gmmopt.infoz.hess  Hessian updating (see gmmS function)     ['gn']
%
%   gmmopt.gmmit  Number of GMM iterations (NaN is iterated)	[2]
%   gmmopt.maxit  Cap on number of GMM iterations		[25]
%   gmmopt.tol    Convergence criteria for iter. GMM		[1e-7]
%   gmmopt.W0     Initial GMM weighting matrix			['Z']
%	'I' = Identity, 'Z' = Instruments (Z'Z), 'C' = Calculate from b, 
%       'Win' = Fixed passed as Win, myfile = user's own m-file
%   gmmopt.W      Subsequent GMM Weighting Matrix               ['S']
%       'S' = inverse Spectral Density from gmmS
%       myfile = user's m-file name
%   gmmopt.S      Type of Spectral Density matrix		['NW']

%	'W'=White, 'NW'=Newey-West (Bartlett), 'G'=Gallant (Parzen)
%	'H'=Hansen (Truncated), 'AM'=Andrews-Monahan
%   gmmopt.aminfo structure if gmmopt.S='AM'.   See ANDMON.M
%   gmmopt.lags   Lags used in truncated kernel for S	        [nobs^(1/3)]
%   gmmopt.wtvec  User-provided vector of wts for truncated kernel
%   gmmopt.Strim  Contols demeaning of moments in calc of S	[1]
%	0 = none, 1 = detrend e, 2 = detrend Z'e
%   gmmopt.Slast  1 to recalc S at final param est. 2 updates W	[1]
%   gmmopt.null   Vector of null hypotheses for t-stats		[0]
%   gmmopt.prt    Fid for printing (0=none,1=screen,else file)	[1]
%   gmmopt.plot   1 does some plots, else suppress		[1]
%   gmmopt.vname  Optional k-vector of parameter names
%
% Y  "Dependent" variables
% X  "Independent" variables
% Z  Instruments (can be same as X)
% Win User-defined Initial weighting matrix                     OPTIONAL
%    To use a function to calculate W0, don't use Win, but set
%    gmmopt.W0 to 'U' and give the m-file name in gmmopt.W
%

disp('Memory 256')

disp('==========')





infoz.momt='gmmnb';			% moment conditions
infoz.jake='gmmnbj';			% Analytical Deriv of moment cond.

infoz.step='step2';			% Step length algorithm
infoz.hess='bfgs';			% Hessian (search direction)
infoz.maxit=250;
infoz.tol=5e-8;

gmmopt.infoz = infoz;
gmmopt.tol = 5e-8;			% Convergence tolerance
gmmopt.gmmit = 10;			% Number of GMM iterations
gmmopt.W0 = 'Z';			% Initial weighting matrix
gmmopt.W='S';				% Subsequent wtg matrix optimal
gmmopt.S='NW';				% Select subsequent wtg matrix
gmmopt.lags=5;				% Lags in weighting matrix
gmmopt.prt=1;				% Control printing
gmmopt.plot=0;				% change to 1 if you want various plots of the moment conditions


data=csvread('Mem256matlabdata.csv');

% rows with last observation :
% s=0, cnum=1: 289
% s=0, cnum=2: 575
% s=3, cnum=1: 864
% s=3, cnum=2: 1150

numdate=data(:,1);
s=data(:,2);
cnum=data(:,3);
q1=data(:,4);
q2=data(:,5);
q3=data(:,6);
border=data(:,7);
sun=data(:,8);
mon=data(:,9);
tue=data(:,10);
wed=data(:,11);
thu=data(:,12);
fri=data(:,13);
sat=data(:,14);
weekend=data(:,15);
boost=data(:,16);
lnp1=data(:,17);
lnp2=data(:,18);
lnp3=data(:,19);
lnminp=data(:,20);
speed133=data(:,21);
boost133=data(:,22);
smk133=data(:,23);
ndate133=data(:,24);
jan=data(:,25);
feb=data(:,26);
mar=data(:,27);
apr=data(:,28);
may=data(:,29);
jun=data(:,30);
jul=data(:,31);
aug=data(:,32);
sep=data(:,33);
oct=data(:,34);
nov=data(:,35);
dec=data(:,36);
p1diff=data(:,37);
t1=data(:,38)/100;
t2=data(:,39)/100;
t3=data(:,40)/100;
t4=data(:,41)/100;
t5=data(:,42)/100;
t6=data(:,43)/100;
t7=data(:,44)/100;
t8=data(:,45)/100;
t9=data(:,46)/100;
t10=data(:,47)/100;
t11=data(:,48)/100;
t12=data(:,49)/100;
p2diff=data(:,50);
p3diff=data(:,51);
icost1=data(:,52);
icost2=data(:,53);
icost3=data(:,54);
icost4=data(:,55);
icost9=data(:,56);
icost10=data(:,57);
icost11=data(:,58);
icost12=data(:,59);
ipmin1=data(:,60);
ipmin2=data(:,61);
ipdiff1=data(:,62);
ipdiff2=data(:,63);
ipdiff3=data(:,64);
irank1=data(:,65);
irank2=data(:,66);
irank3=data(:,67);
ip2diff=data(:,68);
ip3diff1=data(:,69);
ip3diff2=data(:,70);
lnp2hat100=data(:,71);
lnp3hat100=data(:,72);
lnp2hat133=data(:,73);
lnp3hat133=data(:,74);

cons=ones(1150,1);


% For Elasticities.xls
disp('--- NO INSTRUMENTS : 256 MB PC 100 CHIP ---')
disp('--EQUIVALENT TO STATA NBREG ANALYSIS--')
disp('-- LOW QUALITY PC100--')
disp('Newey-West Standard Errors for each station, independent across stations')

Y = q1(1:575,:);
X =[cons(1:575,:) border(1:575,:) lnp1(1:575,:) lnp2(1:575,:) lnp3(1:575,:) lnminp(1:575,:) weekend(1:575,:) boost(1:575,:) t1(1:575,:) t2(1:575,:) t3(1:575,:) t4(1:575,:) t5(1:575,:) t6(1:575,:) t7(1:575,:) t8(1:575,:) t9(1:575,:) t10(1:575,:) t11(1:575,:)];
Z=X; % no instruments
T1=289;
gmmopt.vname = strvcat('cons','border', 'lnp1', 'lnp2','lnp3','lnminp','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11');	% variable names
%b=[5.05;-1.53;0.86;-0.73;-0.63;-0.59;-0.70;0.02;-0.08;0.12;-0.10;0.04;0.03;-0.05;0.00;0.02;-0.02;-0.06];
b=[5;-2;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];

gmmopt.null=[0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];

gmmout=gmmas(b,gmmopt,Y,X,Z,T1);



disp('--MEDIUM QUALITY PC100--')
disp('Newey-West Standard Errors for each station, independent across stations')

Y = q2(1:575,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);

disp('--HIGH QUALITY PC100--')
disp('Newey-West Standard Errors for each station, independent across stations')

Y = q3(1:575,:);
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);


% For Elasticities.xls
disp('--- NO INSTRUMENTS : 256 MB PC 133 CHIP ---')
disp('--EQUIVALENT TO STATA NBREG ANALYSIS--')
disp('-- LOW QUALITY PC133--')
disp('Newey-West Standard Errors for each station, independent across stations')


Y = q1(576:1150,:);
X =[cons(576:1150,:) border(576:1150,:) lnp1(576:1150,:) lnp2(576:1150,:) lnp3(576:1150,:) lnminp(576:1150,:) weekend(576:1150,:) boost(576:1150,:) t1(576:1150,:) t2(576:1150,:) t3(576:1150,:) t4(576:1150,:) t5(576:1150,:) t6(576:1150,:) t7(576:1150,:) t8(576:1150,:) t9(576:1150,:) t10(576:1150,:) t11(576:1150,:)];
Z=X; % no instruments
T1=289;
gmmopt.infoz.hess='gn'
gmmopt.vname = strvcat('cons','border', 'lnp1','lnp2','lnp3','lnminp','weekend','boost','t1', 't2','t3','t4','t5','t6','t7','t8','t9','t10','t11');	% variable names
b=[14.18;-1.29;-5.63;.75;-.6;3.13;-0.57;-0.32;0.004;0.037;-0.01;-0.03;-0.02;0.04;-0.06;0.03;0;-0.01;-0.04];
%b=[5;-1;0;0;0;0;0;0;0;0;;0;0;0;0;0;0;0;0;0];

% NOTE:  MODIFIED JUNE 2003 BY N. BARCZI - STARTING VALUES TAKEN FROM NBREG
% STATA OUTPUT

gmmopt.null=[0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];

gmmout=gmmas(b,gmmopt,Y,X,Z,T1);



disp('--MEDIUM QUALITY PC133--')
disp('Newey-West Standard Errors for each station, independent across stations')
Y = q2(576:1150,:);
X =[cons(576:1150,:) border(576:1150,:) lnp1(576:1150,:) lnp2(576:1150,:) lnp3(576:1150,:) lnminp(576:1150,:) weekend(576:1150,:) boost(576:1150,:) t1(576:1150,:) t4(576:1150,:) t5(576:1150,:) t6(576:1150,:) t7(576:1150,:) t8(576:1150,:) t9(576:1150,:) t10(576:1150,:) t11(576:1150,:)];
Z=X; % no instruments
T1=289;
gmmopt.vname = strvcat('cons','border', 'lnp1','lnp2','lnp3','lnminp','weekend','boost','t1','t4','t5','t6','t7','t8','t9','t10','t11');	% variable names
b=[19.05;-0.60;0;-2.24;-3.29;1.76;-0.58;-0.24;0.05;-0.10;0.09;-0.02;-0.05;0.02;0.00;-0.01;0.00];

% NOTE:  MODIFIED JUNE 2003 BY N. BARCZI - STARTING VALUES TAKEN FROM NBREG
% STATA OUTPUT - DUE TO LOW SALES EARLY IN THE SAMPLE, WE USE ONLY A SINGLE
% SLOPE COEFFICIENT (T1) IN PLACE OF T1-T3.

gmmopt.null=[0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];

gmmout=gmmas(b,gmmopt,Y,X,Z,T1);




% HIGH QUALITY
disp('--HIGH QUALITY PC133--')
disp('Newey-West Standard Errors for each station, independent across stations')
Y = q3(576:1150,:);
X =[cons(576:1150,:) border(576:1150,:) lnp1(576:1150,:) lnp2(576:1150,:) lnp3(576:1150,:) lnminp(576:1150,:) weekend(576:1150,:) boost(576:1150,:) t1(576:1150,:) t2(576:1150,:) t3(576:1150,:) t4(576:1150,:) t5(576:1150,:) t6(576:1150,:) t7(576:1150,:) t8(576:1150,:) t9(576:1150,:) t10(576:1150,:) t11(576:1150,:)];
Z=X; % no instruments
T1=289;
gmmopt.vname = strvcat('cons','border','lnp1','lnp2','lnp3','lnminp','weekend','boost','t1','t2','t3','t4','t5','t6','t7','t8','t9','t10','t11');	% variable names
b=[9.25;-0.44;0;0.83;-2.77;-0.40;-0.45;-0.54;0.20;-0.20;-0.01;0.03;-0.04;0.02;-0.01;0.00;0.00;-0.01;0.04];			% Starting values
gmmopt.null = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0];			% Null hypothesis
gmmout=gmmas(b,gmmopt,Y,X,Z,T1);

diary off



