function [m,e]=gmmnb(b,infoz,stat,Y,X,Z)
% GMMNB  Evaluates gmmnb(b) for use
%        with the GMM package. Negative Binomial Model.
%
%   b:    k-vector of model parameters
%   X:    (nobs x k) matrix of exogenous variables
%   Y:    (nobs x neq) matrix of endogenous variables
%   Z:    (nobs x nz) vector of instruments
%
%   e:  (nobs x neq) matrix of conditions of interest
%   m:  north-vector of orthog. cond. from stacking Z'h
%
% For this application:
%  single moment condition is E(y.*exp(-X*b) - 1)=0 
%  y [n x 1] is the count (although in the example data I use a continuous +ve variable)
%  X [n x k]  
%  b [k x 1]
%  e [n x 1] = y.*exp(-X*b) - 1 
%  m = Z'e/N [# instruments x 1]

[N, neq] = size(Y);
k = cols(Z);
north = neq*k;

e = Y.*exp(-X*b)-ones(N,1);
m = reshape(Z'*e/N,north,1);
