/*----------------------------------------------------------------
                             MARKUPG.DO

Program computes markup information used in Markup table (and as
input to Elasticities.XLS spreadsheet which computes predicted 
markups for the table).

Program modified from submit04\markup_504g.do to use latest version
of each dataset.

------------------------------------------------------------------ */

log using markupg.log, replace

cd "\\bbking\psellison\Econometrica\"

use markupinput128.dta, clear
sort numdate
merge numdate using instr_0.dta

tab _merge
drop if _merge~=3  
drop _merge

sort numdate

merge numdate using instr_3.dta

tab _merge
drop if _merge~=3  
drop _merge


sort numdate s
merge numdate s using instrpwatch.dta

tab _merge

sort numdate cnum

gen year=year(numdate)
gen month=month(numdate)

drop if q1==.|q2==.|q3==.|p1==.|p2==.|p3==.|border==.

drop if month==12

for num 1/3:  replace pX = 0.975*pX + 10.75 if cnum==1
for num 1/3:  replace pX = 0.975*pX + 9.85 if cnum==2
for num 1 2 3 9 10 11: replace icostX = 1.01*icostX + 8.50

gen markup1 = (p1 - icost1)/p1 if s==0
replace markup1 = (p1 - icost9)/p1 if s==3


gen markup2 = (p2 - icost2)/p2 if s==0
replace markup2 = (p2 - icost10)/p2 if s==3

gen markup3 = (p3 - icost3)/p3 if s==0
replace markup3 = (p3 - icost11)/p3 if s==3

gen r1=p1*q1
gen r2=p2*q2
gen r3=p3*q3
gen r=r1+r2+r3


sum markup1 [aw=r1] if s==0
sum markup1 [aw=r1] if s==3
sum markup2 [aw=r2] if s==0
sum markup2 [aw=r2] if s==3
sum markup3 [aw=r3] if s==0
sum markup3 [aw=r3] if s==3

gen q = q1+q2+q3

gen markup = (markup1*q1 + markup2*q2 + markup3*q3)/(q)

gen rmarkup=(markup1*p1*q1+markup2*p2*q2+markup3*p3*q3)/r
sum rmarkup [aw=r] if s==0
sum rmarkup [aw=r] if s==3

save mark128.dta, replace
clear

use 256\markupinput256.dta, clear
sort numdate
merge numdate using 256\instr_0.dta

tab _merge
drop if _merge~=3  
drop _merge

sort numdate

merge numdate using 256\instr_3.dta

tab _merge
drop if _merge~=3  
drop _merge


sort numdate s
merge numdate s using 256\instrpwatch

tab _merge

sort numdate cnum

gen year=year(numdate)
gen month=month(numdate)

drop if q1==.|q2==.|q3==.|p1==.|p2==.|p3==.|border==.

drop if month==12

for num 1/3:  replace pX = 0.975*pX + 10.75 if cnum==1
for num 1/3:  replace pX = 0.975*pX + 9.85 if cnum==2
for num 5 6 7 13 14 15: replace icostX = 1.01*icostX + 8.50

gen widelowc=0
gen narlowc=0
replace widelowc=1 if numdate>14854 & numdate < 14917
replace narlowc=1 if numdate > 14866 & numdate < 14910


gen markup1 = (p1 - icost5)/p1 if s==0
replace markup1 = (p1 - icost13)/p1 if s==3

gen markup2 = (p2 - icost6)/p2 if s==0
replace markup2 = (p2 - icost14)/p2 if s==3

*gen markup3 = (p3 - icost7)/icost7 if s==0
gen markup3 = (p3 - icost7)/p3 if s==0 & icost7 > 40
replace markup3 = (p3 - icost15)/p3 if s==3

gen r1=p1*q1
gen r2=p2*q2
gen r3=p3*q3
gen r=r1+r2+r3

gen q = q1+q2+q3
gen markup = (markup1*q1 + markup2*q2 + markup3*q3)/(q)


sum markup1 [aw=r1] if s==0
sum markup1 [aw=r1] if s==3
sum markup2 [aw=r2] if s==0
sum markup2 [aw=r2] if s==3
sum markup3 [aw=r3] if s==0
sum markup3 [aw=r3] if s==3

gen rmarkup=(markup1*p1*q1+markup2*p2*q2+markup3*p3*q3)/r
sum rmarkup [aw=r] if s==0
sum rmarkup [aw=r] if s==3

save mark256.dta, replace
clear

log close



