/***********************************************************/
/*                      memlogit.do                        */
/*  this program estimates a logit model with market share */
/*  of 1st Choice Memory (A) (with market consisting of    */
/*  their sales and those of PCBoost.com (B)) on the LHS,  */
/*  and log(1+lowPRank)(A) - log(1+lowPRank)(B) and        */
/*  log(Pmid)(A) - log(Pmid)(B) on the RHS                 */
/***********************************************************/                   
/* i am editing this program to add fixed effects and      */
/* estimate three regressions, one where all memory obs    */
/* are stacked and estimated together and one each that    */
/* just have medium quality and high quality.              */
/* sfe                                May 13, 2004         */
/* i ran these using linear regression instead of logit    */
/***********************************************************/

capture log close
cd "\\bbking\psellison\Econometrica\"

clear
log using memlogit.log, replace

/**************/
/* PC100 128MB*/
/**************/

use ml128.dta

/* order of variables is :  
numdate
s		speed
cnum		firm identifier
q1		\
q2		 > dependent variable for three qualities
q3		/
border
weekend
boost
lnp1
lnp2
lnp3
lnminp
t1
t2
t3
t4
t5
t6
t7
t8
t9
t10
t11
t12
irankc	 \

ip1cnew	  > cost-based instruments
ip2c		 /
ip3c		/
irankos	\
ip1os		 \
ip2os 	  > other-speed-based instruments
ip3os		 /


r1		\
r2		 \
r3		  \
r4		   \
r5		    \
r6		     \
r7
r8			  > Added by JAB, 7-11-07
r9
r10	  	     /
r11		    /
r12		   /


rows with last observation :
s=0, cnum=1:   343
s=0, cnum=2:   683
s=3, cnum=1:   989
s=3, cnum=2:  1291

*/

keep if s==0
keep numdate cnum q2 q3 border lnp2 lnp3
reshape wide q2 q3 border lnp2 lnp3, i(numdate) j(cnum)

/* variables are now:

numdate
q21 
q22 
q31 
q32 
border1 
border2
lnp21
lnp22
lnp31
lnp32
s1
s2

where the last digit represents the old variable cnum:
1 = 1st Choice Memory,
2 = PCBoost.com

*/

/* set up LHS variables */
/* NOTE:  MISSING VALUES FOR EITHER COMPANY WILL GENERATE MISSING OBSERVATIONS FOR REGRESSION VARIABLES. */

gen mktshrmid = q21/(q21+q22)
gen mktshrhi = q31/(q31+q32)
gen qmid1=q21
gen qmid=q21+q22
gen qhi1=q31
gen qhi=q31+q32

/* set up RHS variables */

gen borderdiff = border1 - border2
gen lnp2diff = lnp21 - lnp22
gen lnp3diff = lnp31 - lnp32
gen listdiff=0
replace listdiff=1 if border1<=ln(13) & border2>ln(13)
replace listdiff=-1 if border1>ln(13) & border2<=ln(13)

gen dset = 1

save log1280.tmp, replace

/* logit regressions */

/*logistic mktshrmid borderdiff lnp2diff
logit
logistic mktshrhi borderdiff lnp3diff
logit*/

clear

/**************/
/* PC133 128MB*/
/**************/

use ml128.dta

keep if s==3
keep numdate cnum q2 q3 border lnp2 lnp3
reshape wide q2 q3 border lnp2 lnp3, i(numdate) j(cnum)

/* variables are now:

numdate
q21 
q22 
q31 
q32 
border1 
border2
lnp21
lnp22
lnp31
lnp32
s1
s2

where the last digit represents the old variable cnum:
1 = 1st Choice Memory,
2 = PCBoost.com

*/

/* set up LHS variables */
/* NOTE:  MISSING VALUES FOR EITHER COMPANY WILL GENERATE MISSING OBSERVATIONS FOR REGRESSION VARIABLES. */

gen mktshrmid = q21/(q21+q22)
gen mktshrhi = q31/(q31+q32)
gen qmid1=q21
gen qmid=q21+q22
gen qhi1=q31
gen qhi=q31+q32


/* set up RHS variables */

gen borderdiff = border1 - border2
gen lnp2diff = lnp21 - lnp22
gen lnp3diff = lnp31 - lnp32
gen listdiff=0
replace listdiff=1 if border1<=ln(13) & border2>ln(13)
replace listdiff=-1 if border1>ln(13) & border2<=ln(13)

gen dset = 2

save log1283.tmp, replace

/* logit regressions */

/*logistic mktshrmid borderdiff lnp2diff
logit
logistic mktshrhi borderdiff lnp3diff
logit*/

clear

/**************/
/* PC100 256MB*/
/**************/


use 256\Mem256matlabdata.dta

/* order of variables is : 
1. numdate, 2.s, 3.cnum, 4.q1,5.q2,6.q3,7. border, 8.sun,9.mon,10.tue,11.wed,12.thur,13.fri,14.sat,15.weekend,16.boost,17.lnp1,18.lnp2,19.lnp3,20.lnminp,21.speed133,22.boost*133,23.smk*133,
24.ndate*133,25.jan,26.feb,27.mar,28.apr,29.may,30.jun,31.jul,32.aug,33. sep,34.oct,35.nov,36.dec,37.p1diff,38.t1,39.t2,40.t3,41.t4, 42. t5,
 43. t6, 44. t7, 45. t8, 46. t9, 47. t10, 48. t11, 49. t12, 50. p2diff, 51. p3diff,  
52. icost1, 53. icost2, 54. icost3, 55. icost4, 56. icost9, 57. icost14, 58. icost15, 59.icost16,
60. ipmin1 61. ipmin2 62. ipdiff1 63. ipdiff2 64.  ipdiff3 65.  irank1 66. irank2 67. irank3  68. ip2diff 69. ip3diff1 70. ip3diff2 71. lnp2hat100 72. lnp3hat100 73. lnp2hat133 74. lnp3hat133
  

rows with last observation :

s=0, cnum=1: 289
s=0, cnum=2: 575
s=3, cnum=1: 864
s=3, cnum=2: 1150

*/

keep if s==0
keep numdate cnum q2 q3 border lnp2 lnp3
reshape wide q2 q3 border lnp2 lnp3, i(numdate) j(cnum)

/* variables are now:

numdate
q21 
q22 
q31 
q32 
border1 
border2
lnp21
lnp22
lnp31
lnp32
s1
s2

where the last digit represents the old variable cnum:
1 = 1st Choice Memory,
2 = PCBoost.com

*/

/* set up LHS variables */
/* NOTE:  MISSING VALUES FOR EITHER COMPANY WILL GENERATE MISSING OBSERVATIONS FOR REGRESSION VARIABLES. */

gen mktshrmid = q21/(q21+q22)
gen mktshrhi = q31/(q31+q32)
gen qmid1=q21
gen qmid=q21+q22
gen qhi1=q31
gen qhi=q31+q32


/* set up RHS variables */

gen borderdiff = border1 - border2
gen lnp2diff = lnp21 - lnp22
gen lnp3diff = lnp31 - lnp32
gen listdiff=0
replace listdiff=1 if border1<=ln(13) & border2>ln(13)
replace listdiff=-1 if border1>ln(13) & border2<=ln(13)

gen dset = 3

save log2560.tmp, replace


/* logit regressions */

/*logistic mktshrmid borderdiff lnp2diff
logit
logistic mktshrhi borderdiff lnp3diff
logit*/

clear

/**************/
/* PC133 256MB*/
/**************/

use 256\Mem256matlabdata.dta

keep if s==3
keep numdate cnum q2 q3 border lnp2 lnp3
reshape wide q2 q3 border lnp2 lnp3, i(numdate) j(cnum)

/* variables are now:

numdate
q21 
q22 
q31 
q32 
border1 
border2
lnp21
lnp22
lnp31
lnp32
s1
s2

where the last digit represents the old variable cnum:
1 = 1st Choice Memory,
2 = PCBoost.com

*/

/* set up LHS variables */
/* NOTE:  MISSING VALUES FOR EITHER COMPANY WILL GENERATE MISSING OBSERVATIONS FOR REGRESSION VARIABLES. */

gen mktshrmid = q21/(q21+q22)
gen mktshrhi = q31/(q31+q32)
gen qmid1=q21
gen qmid=q21+q22
gen qhi1=q31
gen qhi=q31+q32


/* set up RHS variables */

gen listdiff=0
replace listdiff=1 if border1<=ln(13) & border2>ln(13)
replace listdiff=-1 if border1>ln(13) & border2<=ln(13)
gen borderdiff = border1 - border2
gen lnp2diff = lnp21 - lnp22
gen lnp3diff = lnp31 - lnp32


gen dset = 4

save log2563.tmp, replace


/* logit regressions */

/*logistic mktshrmid borderdiff lnp2diff
logit
logistic mktshrhi borderdiff lnp3diff
logit*/

/*clear*/

append using log2560.tmp
append using log1283.tmp
append using log1280.tmp

gen fe10 = 0
replace fe10=1 if dset==1
gen fe13 = 0
replace fe13=1 if dset==2
gen fe20 = 0
replace fe20=1 if dset==3
gen fe23 = 0
replace fe23=1 if dset==4

blogit qmid1 qmid borderdiff lnp2diff lnp3diff listdiff fe13 fe20 fe23 numdate, cluster(numdate)
blogit qhi1 qhi borderdiff lnp2diff lnp3diff listdiff fe13 fe20 fe23 numdate, cluster(numdate)

! del *.tmp
log close





